<%@ LANGUAGE=vbscript %>
<%
' ----- Copyright --------------------------------------------------------
' (c)2000 Copyright QSI Payments, Inc. - All Rights Reserved
' Copyright Statement: http://www.qsipayments.com/copyright/Payment_Client
' ------------------------------------------------------------------------
'
' NAME
' ====
' SSL_DO.asp
'
' PURPOSE
' =======
' Creates a Digital Order and sends it to the Payment Server.
'
' PAYMENT CLIENT VERSION
' ======================
' This module assumes v1.1.54 of the payment client.
'
' REVISION HISTORY
' ================
' v1.0				10 March 2000		Initial version
'
' INPUTS
' ======
'	SessionID			Your (unique) identifier for the transaction
'	MerchantID			Your Merchant ID - issued to you by the payment service or bank
'	PurchaseAmount		Purchase Amount (Cents)
'	Locale			Defines the langauge to use when presenting payment pages
'	ReturnURL			Where to send the Digital Receipt to
'
' OUTPUTS
' =======
'	If no errors detected
'		DigitalOrder	Sent to Payment Server (via browser redirection)
'	Else
'		ErrorCode		Sent to sErrorPage (via browser redirection)
'		Exception		Returns Payment Client Exception (where generated)
'
'	ErrorCode Values
'	================
'	10	Payment Client has not initialised correctly.
'		- Check the installation of the payment client.
'	11	Digital Order has not created correctly.
'		- Check input parameters.
'
' VARIABLES
' =========
'	objPayClient		Payment Client object
'	sDigitalOrder		Digital Order string
'	lAmount			String value (PurchaseAmount) is cast to long (lAmount)
'	sErrorPage			Name of Error Handler
'	nErrorCode 			Error Code number
'	sException			Payment Client Exception (where generated)
'
' ==========================================================================
'
' Initialisation
' ==============
'	Define the error constants
	const No_Error 		= 0
	const ERR_PayClient 	= 10
	const ERR_DigitalOrder	= 11

'	Define Error Handler
	sErrorPage = "./SSL_Order_Error.asp"

'	Initialise ErrorCode - set to No Errors
	nErrorCode = No_Error
	sException	= ""

'	Turn off default error checking, as any errors are explicitly handled
	on error resume next

'	Stop the page being cached on the web server
	Response.Expires = 0

'	Retrieve input variables from the prior form
	sSessionID		= Request.Form("SessionID")
	sMerchantID		= Request.Form("MerchantID")
	sPurchaseAmount	= Request.Form("PurchaseAmount")
	sLocale		= Request.Form("Locale")
	sReturnURL		= Request.Form("ReturnURL")

'	The amount must be converted to a long for processing
	lAmount		= CLng(sPurchaseAmount)

' Create Payment Client Object
' ============================
'	Create Payment Client object
	set objPayClient = Server.CreateObject("PaymentClient.com.COMClient")

'	Test the Payment Client object created corectly
	if objPayClient.echo("Test") <> "echo:Test" then
		nErrorCode = ERR_PayClient
	end if

' Generate Digital Order
' ======================
'	if no errors ...
	if nErrorCode = No_Error then
'		Initialise Digital Order
		sDigitalOrder = ""
		sDigitalOrder = objPayClient.getDigitalOrder( _
		    	sSessionID, _
			sMerchantID, _
		      lAmount, _
	      	sLocale, _
		      sReturnURL)

'		Check for errors
		if len(sDigitalOrder) = 0 then
			nErrorCode = ERR_DigitalOrder
			sException	= objPayClient.getResultField("PaymentClient.Error")
		end if
	end if

'	Nullify the Payment Client object
	set objPayClient = nothing

' Send Digital Order
' ==================
'	if no errors ...
	if nErrorCode = No_Error then
		Response.Redirect sDigitalOrder
	else
'		Pass control to the error handler
		sErrorPage = sErrorPage &	"?ErrorCode="	& nErrorCode & _
							"&Exception="	& sException
		Response.Redirect sErrorPage
	end if
%>